SignalRConnectionOptions class

Constructors

SignalRConnectionOptions({required String serverUrl, String? accessToken, Duration reconnectInterval = const Duration(seconds: 5), int maxRetryAttempts = 5, bool autoReconnect = true, dynamic onError(String)?, bool useSecureConnection = true, HttpTransportType transport = HttpTransportType.webSockets, bool skipNegotiation = false, bool bypassSslCertificateValidation = false})

Properties

accessToken String?
final
autoReconnect bool
final
bypassSslCertificateValidation bool
When true, accepts invalid or self-signed TLS certificates. Only effective on mobile/desktop (IO platforms); browsers enforce their own certificate policies and ignore this flag. WARNING: Do not enable in production.
final
hashCode int
The hash code for this object.
no setterinherited
maxRetryAttempts int
final
onError → dynamic Function(String)?
final
reconnectInterval Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverUrl String
final
skipNegotiation bool
final
transport → HttpTransportType
final
useSecureConnection bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited